@@ -6,8 +6,7 @@
 #include <stan/lang/ast.hpp>
 
 BOOST_FUSION_ADAPT_STRUCT(stan::lang::range,
-                          (stan::lang::expression, low_)
-                          (stan::lang::expression, high_) )
-
+                          (stan::lang::expression, low_)(stan::lang::expression,
+                                                         high_))
 
 #endif
