@@ -1,6 +1,7 @@
 #ifndef STAN_MATH_PRIM_SCAL_FUN_IF_ELSE_HPP
 #define STAN_MATH_PRIM_SCAL_FUN_IF_ELSE_HPP
 
+#include <stan/math/prim/meta.hpp>
 #include <boost/math/tools/promotion.hpp>
 
 namespace stan {
@@ -21,8 +22,8 @@ namespace math {
  * @param y_false Value to return if condition is false.
  */
 template <typename T_true, typename T_false>
-inline typename boost::math::tools::promote_args<T_true, T_false>::type if_else(
-    const bool c, const T_true y_true, const T_false y_false) {
+inline return_type_t<T_true, T_false> if_else(const bool c, const T_true y_true,
+                                              const T_false y_false) {
   return c ? y_true : y_false;
 }
 
